=======
pybliss
=======

.. module:: pybliss

*pybliss* provides Python wrappers for the `bliss tool
<https://users.aalto.fi/~tjunttil/bliss/>`_. Bliss relies on faster algorithms
[bliss_2007]_, and sophisticated pruning techniques [bliss_2011]_ to accelerate
finding automorphisms of a graph. Subsequently, it also provides tools for
obtaining a canonical form of a graph.

The rest of this manual is structured as follows. The install instructions are
outlined in :ref:`how_to_install`. We provide a brief tutorial in a Jupyter
notebook. The API reference is generated in Sec. “:ref:`api`\ ”.

.. toctree::
    :maxdepth: 2
    :caption: Contents:
  
    install
    notebooks/tutorial.ipynb
    api
    refs

    🚀 Github <https://github.com/kaushikcfd/pybliss>
    💾 Download Releases <https://pypi.org/project/pybliss>
